@@ -29,7 +29,7 @@ from sklearn import svm
 import os, random, shutil
 
 class octid:
-    def __init__(self, model = 'GoogleNet',customised_model = False, feature_dimension = 3, outlier_fraction_of_SVM = 0.03, traning_dataset=None, validation_dataset=None, unlabeled_dataset=None):
+    def __init__(self, model = 'googlenet',customised_model = False, feature_dimension = 3, outlier_fraction_of_SVM = 0.03, traning_dataset=None, validation_dataset=None, unlabeled_dataset=None):
         self.model_name = model
         self.dim = feature_dimension
         self.templates_path = traning_dataset
@@ -37,59 +37,59 @@ class octid:
         self.unknown_path = unlabeled_dataset
         self.SVM_nu = outlier_fraction_of_SVM
         if not customised_model:
-            if self.model_name == 'AlexNet':
+            if self.model_name == 'alexnet':
                 self.model = models.alexnet(pretrained=True)
-            elif self.model_name == 'VGG-11':
+            elif self.model_name == 'vgg11':
                 self.model = models.vgg11(pretrained=True)
-            elif self.model_name == 'VGG-13':
+            elif self.model_name == 'vgg13':
                 self.model = models.vgg13(pretrained=True)
-            elif self.model_name == 'VGG-16':
+            elif self.model_name == 'vgg16':
                 self.model = models.vgg16(pretrained=True)
-            elif self.model_name == 'VGG-19':
+            elif self.model_name == 'vgg19':
                 self.model = models.vgg19(pretrained=True)
-            elif self.model_name == 'VGG-11 with batch normalization':
+            elif self.model_name == 'vgg11_bn':
                 self.model = models.vgg11_bn(pretrained=True)
-            elif self.model_name == 'VGG-13 with batch normalization':
+            elif self.model_name == 'vgg13_bn':
                 self.model = models.vgg13_bn(pretrained=True)
-            elif self.model_name == 'VGG-16 with batch normalization':
+            elif self.model_name == 'vgg16_bn':
                 self.model = models.vgg16_bn(pretrained=True)
-            elif self.model_name == 'VGG-19 with batch normalization':
+            elif self.model_name == 'vgg19_bn':
                 self.model = models.vgg19_bn(pretrained=True)
-            elif self.model_name == 'ResNet-18':
+            elif self.model_name == 'resnet18':
                 self.model = models.resnet18(pretrained=True)
-            elif self.model_name == 'ResNet-34':
+            elif self.model_name == 'resnet34':
                 self.model = models.resnet34(pretrained=True)
-            elif self.model_name == 'ResNet-50':
+            elif self.model_name == 'resnet50':
                 self.model = models.resnet50(pretrained=True)
-            elif self.model_name == 'ResNet-101':
+            elif self.model_name == 'resnet101':
                 self.model = models.resnet101(pretrained=True)
-            elif self.model_name == 'ResNet-152':
+            elif self.model_name == 'resnet152':
                 self.model = models.resnet152(pretrained=True)
-            elif self.model_name == 'Densenet-121':
+            elif self.model_name == 'densenet121':
                 self.model = models.densenet121(pretrained=True)
-            elif self.model_name == 'Densenet-169':
+            elif self.model_name == 'densenet169':
                 self.model = models.densenet169(pretrained=True)
-            elif self.model_name == 'Densenet-201':
+            elif self.model_name == 'densenet201':
                 self.model = models.densenet201(pretrained=True)
-            elif self.model_name == 'Densenet-161':
+            elif self.model_name == 'densenet161':
                 self.model = models.densenet161(pretrained=True)
-            elif self.model_name == 'Inception v3':
+            elif self.model_name == 'inception_v3':
                 self.model = models.inception_v3(pretrained=True)
-            elif self.model_name == 'GoogleNet':
+            elif self.model_name == 'googlenet':
                 self.model = models.googlenet(pretrained=True)
-            elif self.model_name == 'ShuffleNet V2':
+            elif self.model_name == 'shufflenet_v2_x1_0':
                 self.model = models.shufflenet_v2_x1_0(pretrained=True)
-            elif self.model_name == 'MobileNet V2':
+            elif self.model_name == 'mobilenet_v2':
                 self.model = models.mobilenet_v2(pretrained=True)
-            elif self.model_name == 'ResNeXt-50-32x4d':
+            elif self.model_name == 'resnext50_32x4d':
                 self.model = models.resnext50_32x4d(pretrained=True)
-            elif self.model_name == 'ResNeXt-101-32x8d':
+            elif self.model_name == 'resnext101_32x8d':
                 self.model = models.resnext101_32x8d(pretrained=True)
-            elif self.model_name == 'Wide ResNet-50-2':
+            elif self.model_name == 'wide_resnet50_2':
                 self.model = models.wide_resnet50_2(pretrained=True)
-            elif self.model_name == 'Wide ResNet-101-2':
+            elif self.model_name == 'wide_resnet101_2':
                 self.model = models.wide_resnet101_2(pretrained=True)
-            elif self.model_name == 'MNASNet 1.0':
+            elif self.model_name == 'mnasnet1_0':
                 self.model = models.mnasnet1_0(pretrained=True)
             else:
                 print('model is not available')
